==> deepin-screen-recorder_5.9.6.orig.tar.xz: deepin-screen-recorder-5.9.6/translations/deepin-screen-recorder_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Щелкните на иконке в системном лотке
или снова нажмите на ярлык программы для остановки записи</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Запись</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Скриншот</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Захват экрана</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Сохранение не удалось. Пожалуйста, сохраните файл в своем домашнем каталоге</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Завершение процесса скриншота</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Выберите область</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Сохранить в %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Игнорировать</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Буфер обмена</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Сохранение файла записи с экрана, пожалуйста подождите...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Скриншот</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Запись завершена</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Сохранить в %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Запись</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Захват экрана начнется через %1 секунды</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Введите текст здесь</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Пуск / Скриншот</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Выход/Сохранение</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Рисование</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Настройка размера</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Быстрый пуск</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Скриншот окна</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Скриншот с задержкой</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Скриншот всего экрана</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Прямоугольник</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Эллипс</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Линия</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Карандаш</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Растянуть вверх</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Растянуть вниз</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Растянуть влево</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Растянуть вправо</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Уменьшить размер  сверху</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Уменьшить размер снизу</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Уменьшить ширину слева</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Уменьшить ширину справа</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Показать комбинации клавиш</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Начало записи</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Опции</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Размытие</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Мозаика</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Звук Включен</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Микрофон</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Аудиосистема</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Звук Выключен</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Показать Нажатие Клавиши</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Скрыть нажатие клавиши.</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Веб-камера включена</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Веб-камера выключена</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Показывать щелчки мыши в процессе записи</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Опции</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>Кадры в секунду:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Прямоугольник</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Эллипс</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Линия</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Стрелка</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Карандаш</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Сохранить в</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Рабочий стол</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Изображения</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Папка</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Буфер обмена</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Показать указатель</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Записи</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Щелкните на иконке в системном лотке
или снова нажмите на ярлык программы для остановки записи</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Не поворачивайте экран во время записи</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Запись</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Скриншот</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Захват экрана</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Сохранение не удалось. Пожалуйста, сохраните файл в своем домашнем каталоге</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Завершение процесса скриншота</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Выберите область</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Сохранить в %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Игнорировать</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Буфер обмена</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Сохранение файла записи с экрана, пожалуйста подождите...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Поскольку эффект окна отключен во время процесса записи, запись должна быть остановлена</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Скриншот</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation>Снимок экрана был сохранен в альбоме</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Не удалось создать Снимок экрана</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Запись завершена</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Сохранить в %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Запись</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Захват экрана начнется через %1 секунды</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Введите текст здесь</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Пуск / Скриншот</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Выход/Сохранение</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Настройка размера</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Быстрый пуск</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Скриншот окна</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Скриншот с задержкой</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Скриншот всего экрана</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Прямоугольник</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Эллипс</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Линия</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Карандаш</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Растянуть вверх</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Растянуть вниз</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Растянуть влево</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Растянуть вправо</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Уменьшить размер  сверху</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Уменьшить размер снизу</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Уменьшить ширину слева</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Уменьшить ширину справа</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Показать комбинации клавиш</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Веб-камера</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Начало записи</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Опции</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Старт/Запись</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Мышь</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Инструменты</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Извлечь Текст</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Размытие</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Мозаика</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Звук Включен</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Микрофон</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Аудиосистема</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Звук Выключен</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Показать Нажатие Клавиши</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Скрыть нажатие клавиши.</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Веб-камера включена</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Веб-камера выключена</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Показывать щелчки мыши в процессе записи</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Опции</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>Кадры в секунду:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Прямоугольник</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Эллипс</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Линия</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Стрелка</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Карандаш</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Сохранить в</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Рабочий стол</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Изображения</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Папка</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Буфер обмена</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Показать указатель</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Мышь</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Показать Указатель</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Извлечь Текст</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Отрегулируйте область записи в пределах %1*%2, чтобы получить лучший видеоэффект</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>На данный момент запись экрана не поддерживается</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
</context>
</TS>
